@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2021 */
+/* Copyright (c) Philip Hazel, 1991 - 2012 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: January 2021 */
+/* This file last modified: January 2012 */
 
 /* This is the main header file, imported by all other sources. */
 
@@ -27,67 +27,15 @@
 #include <sys/types.h>
 #include <errno.h>
 
-/* Optionsl B2PF include */
-
-#ifdef SUPPORT_B2PF
-#include <b2pf.h>
-#endif
-
 /* Debugging */
 
 #define DEBUG(x) if (debugging) debug_printf x
 
-
-/*************************************************
-*                Program parameters              *
-*************************************************/
-
-#define B2PF_STACKBSIZE    2000   /* On-stack buffer size */
-#define DEF_MAX_BARS        500   /* Default max bars per movement */
-#define DEF_MAX_MOVEMENTS    50   /* Default max movements */
-#define DRAW_BLOCKSIZE      256   /* Chunk size for draw routines */
-#define DRAW_STACKSIZE      100   /* Size of draw stack */
-#define LAYOUT_MAXSIZE      200   /* Max items in layout list */
-#define MAX_BEAMSIZE        100   /* Should be large enough for anything */
-#define MAX_CHORDSIZE        16   /* 16-note chords should be enough */
-#define MAX_DRAW_VARIABLE    19   /* Max number of a draw variable */
-#define MAX_FONTS            50   /* Maximum number of different fonts */
-#define MAX_INCLUDE          10   /* Max depth of included files */
-#define MAX_MACROARGS        20   /* Max number of macro arguments */
-#define MAX_MACRODEFAULT    256   /* Max length of macro default argument */
-#define MAX_POSTABLESIZE    400   /* Max number of entries */
-#define MAX_UTRANSLATE     1000   /* Max Unicode translations for a font */
-#define MAX_XKEYS            10   /* Max number of custom keys (must be <= 21)*/
-#define MIDI_MAXCHANNEL      16   /* Maximum MIDI channel number */
-#define READ_BUFFERSIZE    2000   /* Input buffer size */
-#define TEXT_QUEUE_SIZE      50   /* Max texts before a note */
-#define WORD_BUFFERSIZE     256   /* Buffer for reading words */
-
-
-/* Maximum stave is defined in terms of the length of the bit vector
-that maps stave presence, suspension, etc. If STAVE_BITVEC_SIZE is
-increased, some tables in tables.c must also be extended. Also, the
-mac_initstave, mac_anystave and mac_samestave macros below must be
-suitably modified. */
-
-#define STAVE_BITVEC_SIZE     2   /* Number of ints in the bit vector */
-#define MAX_STAVE             (STAVE_BITVEC_SIZE * 32 - 1)
-
-/* Typesetting parameters */
-
-#define PAGE_LEFTBARSPACE  8000   /* Space at left of bar */
-
-
-/*************************************************
-*  Macros etc for types and character handling   *
-*************************************************/
-
 /* Some operating systems (naughtily, imo) include a definition for "uchar" in
 the standard header files, so we use "uschar". Solaris has u_char in
 sys/types.h. This is just a typing convenience, of course. */
 
 typedef unsigned char uschar;
-typedef unsigned int  usint;
 
 /* These macros save typing for the casting that is needed to cope with the
 mess that is "char" in ISO/ANSI C. */
@@ -193,7 +141,7 @@ should be one that is always available in the base font, with code less that
 *     Structures used in barhdr.h                *
 *************************************************/
 
-/* We need to define certain structures before including barhdr.h. Other
+/* We need to define certain structures before including barhdr.h. Other 
 structures are defined later, below. */
 
 
@@ -203,7 +151,7 @@ typedef struct {
   int   ident;
   int   rotate;
   int   xdelta;
-  int   ydelta;
+  int   ydelta;  
   uschar *text;
   short int flags;
   short int size;
@@ -215,14 +163,14 @@ addresses. They used to be punned, stuffing pointers into ints, but this
 doesn't work in 64-bit environments. */
 
 typedef struct {
-  usint dtype;             /* data type, eg dd_number */
+  int dtype;                      /* data type, eg dd_number */
   union {
     void *ptr;
     int   val;
-  } d;
-} drawitem;
+  } d;   
+} drawitem;    
 
-/* Types of value in draw programs, stacks, and variables; used in the dtype
+/* Types of value in draw programs, stacks, and variables; used in the dtype 
 field in the structure above for items on the stack and for variables. */
 
 #define dd_any      1      /* Used in the checklist for any type allowed */
@@ -244,23 +192,23 @@ typedef struct tree_node
   }
 tree_node;
 
-/* One heading/footing/footnote. There are three different cases: a text
-string, a drawing, or a PostScript string. They use different subsets of the
-fields in this structure. */
+/* One heading/footing line. */
 
 typedef struct headstr {
   struct headstr *next;
-  int  size;           /* Font size: 0 => PostScript; < 0 => drawing */
-  int  space;          /* Space to follow; must be 0 except for text */
-  uschar *text;        /* String for text or PostScript */
-  /* --- Text string --- */
-  int *matrix;         /* points to transformation or NULL */
-  int  font;           /* initial font */
-  int  stretch;        /* amount to stretch spaces by */
-  int  spaceabove;     /* space above the line of text */
-  /* --- Drawing --- */
-  tree_node *drawing;  /* pointer to the drawing */
-  drawitem *drawargs;  /* drawing arguments */
+  int  stretch;          /* amount to stretch spaces by */
+  int  space;            /* amount of space after line */
+  int  size;             /* 0 => postscript heading; < 0 => drawing */
+  int *matrix;           /* points to transformation or NULL */
+  union {
+    uschar *text;        /* either a pointer to a string */
+    tree_node *drawing;  /* or a pointer to a drawing */
+  } a;
+  union {
+    int  spaceabove;     /* either space above a line of text */
+    drawitem *args;      /* or args for a drawing */
+  } b;
+  int  font;             /* initial font */
 } headstr;
 
 /* Text associated with a line or slur gap */
@@ -280,6 +228,39 @@ typedef struct {
 
 
 
+/*************************************************
+*                Program parameters              *
+*************************************************/
+
+#define def_max_bars        500   /* Default max bars per movement */
+#define draw_blocksize      256   /* Chunk size for draw routines */
+#define draw_stacksize      100   /* Size of draw stack */
+#define layout_maxsize      200   /* Max items in layout list */
+#define max_beamsize        100   /* Should be large enough for anything */
+#define max_chordsize        10   /* 10-note chords should be enough */
+#define max_draw_variable    19   /* Max number of a draw variable */
+#define max_fonts            50   /* Maximum number of different fonts */
+#define max_include          10   /* Max depth of included files */
+#define def_max_movements    50   /* Default max movements */
+#define max_postablesize    400   /* Max number of entries */
+#define read_buffersize    1000   /* Input buffer size */
+#define midi_maxchannel      16   /* Maximum MIDI channel number */
+
+/* Maximum stave is defined in terms of the length of the bit vector
+that maps stave presence, suspension, etc. If stave_bitvec_size is
+increased, some tables in tables.c must also be extended. Also, the
+mac_initstave, mac_anystave and mac_samestave macros below must be
+suitably modified. */
+
+#define stave_bitvec_size     2   /* Number of ints in the bit vector */
+#define max_stave             (stave_bitvec_size * 32 - 1)
+
+/* Typesetting parameters */
+
+#define page_leftbarspace  8000   /* Space at left of bar */
+
+
+
 /*************************************************
 *                  Global Macros                 *
 *************************************************/
@@ -293,6 +274,7 @@ typedef struct {
 #define rc_warning     1
 #define rc_serious     2
 #define rc_failed      3
+#define rc_disaster    4
 
 #define time_common  255
 #define time_cut     254
@@ -300,11 +282,11 @@ typedef struct {
 
 /* If MaxExtraFont is increased, check that font_IdStrings in tables.c contains
 sufficient identifying strings, and that ps_IdStrings in ps.c is of the right
-size too. If MaxFontSizes is changed, the initializing table init_fontsizes in
+size too. If MaxTextFont is changed, the initializing table init_fontsizes in
 tables.c must be made to be the correct size. */
 
-#define MaxFontSizes   20   /* for different text sizes */
-#define MaxExtraFont   12   /* for different faces */
+#define MaxTextFont   12   /* for different text sizes */
+#define MaxExtraFont  12   /* for different faces */
 
 
 /* It is helpful to have names for the vertical offsets of the various lines
@@ -360,7 +342,6 @@ accidental on the relevant line or space. */
 #define text_absolute   0x0800
 #define text_centre     0x1000
 #define text_timealign  0x2000
-#define text_followon   0x4000
 
 /* Flags for stave name texts */
 
@@ -374,21 +355,9 @@ accidental on the relevant line or space. */
 #define clef_oldbass    0x01
 #define clef_oldalto    0x02
 
-/* A maximum is set for transposition - 5 octaves should be ample - and a
-conventional value for "no transposition". */
+/* Conventional value for "no transposition" */
 
-#define max_transpose   60
-#define no_transpose  1000
-
-/* Names for C major and the special key 'N', which behaves like C major (no
-key signature) but does not transpose. There are 42 normal keys (7 letters
-times 2 modes times 3 accidentals) whose values are 0-41. There are also up to
-MAX_XKEYS custom-defined keys, starting at 43. Note that the 64-bit is used in
-some contexts to indicate "reset with naturals". */
-
-#define C_key   2
-#define N_key  42  /* The answer to life, the universe, and everything. */
-#define X_key  43  /* The first custom key */
+#define max_transpose 1000
 
 
 
@@ -396,8 +365,6 @@ some contexts to indicate "reset with naturals". */
 *              Global procedure macros           *
 *************************************************/
 
-#define ROUND(x) ((((x) + sizeof(void *) - 1)/sizeof(void *)) * sizeof(void *))
-
 #define mac_fdiv(f,d) ((int)(((double)(f) * 1000.0)/((double) (d))))
 
 #define mac_muldiv(a,b,c) \
@@ -407,9 +374,8 @@ some contexts to indicate "reset with naturals". */
   main_stavemagn = (curmovt->stavesizes)[i]
 
 #define mac_advancechord(ww) \
-  if ((ww = (b_notestr *)((uschar *)ww + length_table[b_note]))->type == b_Jump) \
-    ww = (b_notestr *) \
-      ((uschar *)(((b_Jumpstr *)ww)->next) + length_table[b_Jump])
+  if ((++ww)->type == b_Jump) \
+    ww = (b_notestr *)((b_Jumpstr *)(((b_Jumpstr *)ww)->next) + 1)
 
 #define mac_couplepitch(p, f) \
   if ((f & (nf_coupleU | nf_coupleD)) != 0) \
@@ -418,9 +384,9 @@ some contexts to indicate "reset with naturals". */
 #define mac_clearstave(a, z) \
   a[z >> 5] &= ~main_bit[z & 0x1f]
 
-/* Needs manual adjustment when STAVE_BITVEC_SIZE changes */
+/* Needs manual adjustment when stave_bitvec_size changes */
 #define mac_initstave(a, b) \
-  a[0] = a[1] = (usint)b
+  a[0] = a[1] = b
 
 #define mac_setstave(a, z) \
   a[z >> 5] |= main_bit[z & 0x1f]
@@ -441,15 +407,15 @@ some contexts to indicate "reset with naturals". */
 #define mac_testNstave2(a, b, z) \
   ((a[z >> 5] & b[z >> 5] & main_bit[z & 0x1f]) == 0)
 
-/* Needs manual adjustment when STAVE_BITVEC_SIZE changes */
+/* Needs manual adjustment when stave_bitvec_size changes */
 #define mac_anystave(a) \
   ((a[0] | a[1]) != 0)
 
-/* Needs manual adjustment when STAVE_BITVEC_SIZE changes */
+/* Needs manual adjustment when stave_bitvec_size changes */
 #define mac_diffstave(a, b) \
   (a[0] != b[0] || a[1] != b[1])
 
-/* Needs manual adjustment when STAVE_BITVEC_SIZE changes */
+/* Needs manual adjustment when stave_bitvec_size changes */
 #define mac_samestave(a, b) \
   (a[0] == b[0] && a[1] == b[1])
 
@@ -486,7 +452,7 @@ enum { movt_default, movt_newpage, movt_thispage, movt_thisline,
 
 /* Skip options for errors */
 
-enum { skip_OFF, skip_EOL, skip_KET, skip_BACKSLASH, skip_BAR };
+enum { skip_EOL, skip_KET, skip_BACKSLASH };
 
 /* Notehead type options. If these are changed, the tables in
 shownote.c must also be changed. No stems are printed for values
@@ -524,24 +490,6 @@ enum { font_rm, font_it, font_bf, font_bi,
 
 #define font_sc 256
 
-/* Give names to error numbers so they can be more easily tracked. */
-
-enum { ERR0,  ERR1,  ERR2,  ERR3,  ERR4,  ERR5,  ERR6,  ERR7,  ERR8,  ERR9,
-       ERR10, ERR11, ERR12, ERR13, ERR14, ERR15, ERR16, ERR17, ERR18, ERR19,
-       ERR20, ERR21, ERR22, ERR23, ERR24, ERR25, ERR26, ERR27, ERR28, ERR29,
-       ERR30, ERR31, ERR32, ERR33, ERR34, ERR35, ERR36, ERR37, ERR38, ERR39,
-       ERR40, ERR41, ERR42, ERR43, ERR44, ERR45, ERR46, ERR47, ERR48, ERR49,
-       ERR50, ERR51, ERR52, ERR53, ERR54, ERR55, ERR56, ERR57, ERR58, ERR59,
-       ERR60, ERR61, ERR62, ERR63, ERR64, ERR65, ERR66, ERR67, ERR68, ERR69,
-       ERR70, ERR71, ERR72, ERR73, ERR74, ERR75, ERR76, ERR77, ERR78, ERR79,
-       ERR80, ERR81, ERR82, ERR83, ERR84, ERR85, ERR86, ERR87, ERR88, ERR89,
-       ERR90, ERR91, ERR92, ERR93, ERR94, ERR95, ERR96, ERR97, ERR98, ERR99,
-       ERR100,ERR101,ERR102,ERR103,ERR104,ERR105,ERR106,ERR107,ERR108,ERR109,
-       ERR110,ERR111,ERR112,ERR113,ERR114,ERR115,ERR116,ERR117,ERR118,ERR119,
-       ERR120,ERR121,ERR122,ERR123,ERR124,ERR125,ERR126,ERR127,ERR128,ERR129,
-       ERR130,ERR131,ERR132,ERR133,ERR134,ERR135,ERR136,ERR137,ERR138,ERR139,
-       ERR140,ERR141,ERR142,ERR143,ERR144,ERR145,ERR146,ERR147,ERR148,ERR149,
-       ERR150,ERR151,ERR152,ERR153,ERR154,ERR155,ERR156 };
 
 
 /*************************************************
@@ -565,48 +513,27 @@ typedef struct {
 /* Items in a kerning table, pointed to from a fontstr */
 
 typedef struct kerntablestr {
-  usint pair;
+  unsigned int pair;
   int kwidth;
 } kerntablestr;
 
 
-/* Items in Unicode translation table, pointed to from a fontstr */
-
-typedef struct utrtablestr {
-  int unicode;
-  int pscode;
-} utrtablestr;
-
-
-/* Font data */
+/* Font data read from AFM file */
 
 typedef struct {
   uschar *psname;                 /* PostScript font name */
   int *widths;                    /* Pointer to basic width table */
-  int *r2ladjusts;                /* Pointer to right-to-left adjusts */
+  int *r2ladjusts;                /* Pointer to right-to-left adjusts */ 
   int *heights;                   /* Pointer to height table, if any */
   int kerncount;                  /* Size of kern table */
-  int utrcount;                   /* Size of utr table */
-  utrtablestr *utr;               /* Unicode translation for nonstd font */
-  tree_node *high_tree;           /* Tree for data for high val stdenc chars */
+  tree_node *high_tree;           /* Tree for data for high val chars */
   kerntablestr *kerns;            /* Pointer to kerning table */
   BOOL stdencoding;               /* True if std encoding */
   BOOL fixedpitch;                /* True if fixed pitch */
   BOOL hasfi;                     /* True if has "fi" */
-  BOOL include;                   /* True if to include in output */
 } fontstr;
 
 
-/* Offsets for special text font sizes and matrices, which follow in the same
-vector as sizes specified by the user. */
-
-#define ff_offset_ts     (MaxFontSizes)
-#define ff_offset_ulay   (ff_offset_ts+1)
-#define ff_offset_olay   (ff_offset_ulay+1)
-#define ff_offset_fbass  (ff_offset_olay+1)
-#define ff_offset_init   (ff_offset_fbass+1)
-#define SIZES_SIZE       (ff_offset_init+1)
-
 /* Structure for overall font sizes at standard magnification, and
 pointers to matrices for font stretching and shearing, where defined. */
 
@@ -620,11 +547,16 @@ typedef struct {
   int fontsize_footnote;
   int fontsize_rehearse;
   int fontsize_triplet;
-  int fontsize_repno;                 /* repeat bar number */
-  int fontsize_restct;                /* long rest count */
+  int fontsize_repno;               /* repeat bar number */
+  int fontsize_restct;              /* long rest count */
   int fontsize_trill;
-  int fontsize_vertacc;               /* vertical accidentals */
-  int fontsize_text[SIZES_SIZE];      /* vector of sizes */
+  int fontsize_vertacc;             /* vertical accidentals */
+  int fontsize_text[MaxTextFont];
+  int fontsize_tsfont;              /* These fonts are sometimes accessed  */
+  int fontsize_ulay;                /* as additional text fonts, using     */
+  int fontsize_olay;                /* the offsets defined below, so if    */
+  int fontsize_fbass;               /* changing, keep the offsets in step. */
+  int fontsize_init;                /* This one too...                     */
 
   /* These must be in the same order as the font sizes, and music must
   be first. */
@@ -642,9 +574,22 @@ typedef struct {
   int *fontmatrix_restct;
   int *fontmatrix_trill;
   int *fontmatrix_vertacc;
-  int *fontmatrix_text[SIZES_SIZE];
+  int *fontmatrix_text[MaxTextFont];
+  int *fontmatrix_tsfont;
+  int *fontmatrix_ulay;
+  int *fontmatrix_olay;
+  int *fontmatrix_fbass;
+  int *fontmatrix_init;
 } fontsizestr;
 
+/* Offsets for special text fonts */
+
+#define ff_offset_ts     (MaxTextFont)
+#define ff_offset_ulay   (ff_offset_ts+1)
+#define ff_offset_olay   (ff_offset_ulay+1)
+#define ff_offset_fbass  (ff_offset_olay+1)
+#define ff_offset_init   (ff_offset_fbass+1)
+
 
 /* Data for spacing at the start of a line */
 
@@ -669,7 +614,6 @@ typedef struct stave_list {
 
 typedef struct snamestr {
   struct snamestr *next;
-  struct snamestr *extra;     /* additional string(s); maybe different options */
   uschar *text;
   tree_node *drawing;
   drawitem  *args;            /* for drawing */
@@ -683,8 +627,7 @@ typedef struct snamestr {
 
 typedef struct ptimestr {
   struct ptimestr *next;
-  int movt_number;          /* movement in which defined */
-  int time;
+  int   time;
   uschar *top;
   uschar *bot;
   uschar  offsettop;
@@ -695,12 +638,10 @@ typedef struct ptimestr {
 
 typedef struct pkeystr {
   struct pkeystr *next;
-  int movt_number;          /* movement in which defined */
   int key;
-  int clef;
+  int clef; 
   uschar *string;
-  uschar *cstring;
-} pkeystr;
+} pkeystr;      
 
 /* One transposed key masquerade item */
 
@@ -710,15 +651,6 @@ typedef struct trkeystr {
   int newkey;
 } trkeystr;
 
-/* One KeyTranspose item */
-
-typedef struct keytransposestr {
-  struct keytransposestr *next;
-  int oldkey;
-  int newkeys[12];
-  int letterchanges[12];
-} keytransposestr;
-
 
 /* Data pertaining to one stave */
 
@@ -754,12 +686,12 @@ routines which use this we cheat by defining a macro "posstaves" instead. */
 typedef struct {
   int  moff;
   int  xoff;
-  int  space;                        /* additional space required */
-  usint stemup[STAVE_BITVEC_SIZE];   /* bitmap of staves where there is an */
-                                     /*  actual stem up, aka "posstaves" */
-  usint stemdown[STAVE_BITVEC_SIZE]; /* ditto for stem down */
-  int  auxid;                        /* identification of auxiliary items */
-                                     /*  (may be -ve) */
+  int  space;                       /* additional space required */
+  int  stemup[stave_bitvec_size];   /* bitmap of staves where there is an */
+                                    /*  actual stem up, aka "posstaves" */
+  int  stemdown[stave_bitvec_size]; /* ditto for stem down */
+  int  auxid;                       /* identification of auxiliary items */
+                                    /*  (may be -ve) */
  } workposstr;
 
 
@@ -788,10 +720,9 @@ typedef struct {
   int   endbar;                /* end bar number */
   int   count;                 /* count of bars */
   int   notespacing[8];        /* notespacing values */
-  usint notsuspend[STAVE_BITVEC_SIZE];  /* not suspended staves */
+  unsigned int notsuspend[stave_bitvec_size];  /* not suspended staves */
   snamestr **stavenames;       /* stave name vector */
-  CBOOL endkey;                /* line ends with key signature */
-  CBOOL endtime;               /* line ends with time signature */
+  CBOOL endkeytime;            /* line ends with key or time signature */
 } pagedatastr;
 
 
@@ -885,8 +816,8 @@ typedef struct {
   int   footnotesep;
   int   gracespacing[2];
   int   gracestyle;
-  int   hflatstyle;
-  int   hsharpstyle;
+  int   hflatstyle; 
+  int   hsharpstyle; 
   int   hairpinlinewidth;
   int   hairpinwidth;
   int   hyphenthreshold;
@@ -894,14 +825,13 @@ typedef struct {
   int   key;
   int   keyspacing;
   int   laststave;
-  int   ledger;
+  int   ledger; 
   int   leftmargin;
   int   linelength;
   int   maxbarcount;
   int   maxbeamslope1;
   int   maxbeamslope2;
   int   movt_opt;
-  int   number;
   int   overlaydepth;
   int   play_tempo;
   int   rehearsalstyle;
@@ -921,9 +851,9 @@ typedef struct {
   int   underlaydepth;
   int   underlaystyle;
 
-  usint breakbarlines[STAVE_BITVEC_SIZE];
-  usint staves[STAVE_BITVEC_SIZE];
-  usint suspend[STAVE_BITVEC_SIZE];
+  unsigned int breakbarlines[stave_bitvec_size];
+  unsigned int staves[stave_bitvec_size];
+  unsigned int suspend[stave_bitvec_size];
 
   int   clefwidths[clef_count];
   int   tailadjusts[8];
@@ -932,12 +862,10 @@ typedef struct {
   CBOOL breverests;
   CBOOL check;
   CBOOL checkdoublebars;
-  CBOOL codemultirests;
   CBOOL fullbarend;
   CBOOL startjoin;
   CBOOL keydoublebar;
   CBOOL keywarn;
-  CBOOL rehearsallsleft;
   CBOOL showtime;
   CBOOL showtimebase;
   CBOOL tiesoverwarnings;
@@ -947,7 +875,7 @@ typedef struct {
   CBOOL underlayextenders;
   CBOOL unfinished;
 
-  signed char playtranspose[MAX_STAVE+1];
+  signed char playtranspose[max_stave+1];
 } movtstr;
 
 /* Layout of the data for an active line gap */
@@ -964,15 +892,14 @@ typedef struct slurstr {
   struct slurstr *next;
   b_slurstr *slur;
   gapstr *gaps;
-  int moff;
-  int x;
-  int y;
-  int maxy;
-  int miny;
-  int lastx;
-  int lasty;
-  int slopeleft;
-  int sloperight;
+  int  x;
+  int  y;
+  int  maxy;
+  int  miny;
+  int  lastx;
+  int  lasty;
+  int  slopeleft;
+  int  sloperight;
   short int count;
   short int section;
 } slurstr;
@@ -1090,9 +1017,9 @@ typedef struct sysblock {
   int       keyxposition;       /* position for key signature */
   int       timexposition;      /* position for time signature */
   int       firstnoteposition;  /* sic */
-  usint     notsuspend[STAVE_BITVEC_SIZE];
+  unsigned int notsuspend[stave_bitvec_size];
                                 /* staves not suspended in this system */
-  usint     showtimes[STAVE_BITVEC_SIZE];
+  unsigned int showtimes[stave_bitvec_size];
                                 /* staves which have starting time signatures */
   short int barstart;           /* starting bar number */
   short int barend;             /* ending bar number */
@@ -1100,11 +1027,9 @@ typedef struct sysblock {
 
 /* Flag bits */
 
-#define sysblock_warnkey   1    /* print additional key signature warning bar */
-#define sysblock_warntime  2    /* ditto, time signature */
-#define sysblock_warn      3    /* mask for either one of the above */
-#define sysblock_stretch   4    /* flag set when stretched */
-#define sysblock_noadvance 8    /* don't advance vertically */
+#define sysblock_warn      1    /* print additional warning bar */
+#define sysblock_stretch   2    /* flag set when stretched */
+#define sysblock_noadvance 4    /* don't advance vertically */
 
 
 /* Layout of data in a head block structure. Up to and including the movement
@@ -1143,7 +1068,7 @@ typedef struct mfstr {
   struct mfstr *next;
   int x;
   int y;
-  usint ch;                 /* Holds up to 4 chars */
+  int ch;  /* Holds up to 4 chars */
 } mfstr;
 
 
@@ -1210,22 +1135,15 @@ extern tree_node *draw_variable_tree;  /* Tree of draw variables */
 extern int  draw_thickness;            /* Line thickness */
 
 extern int  error_count;               /* Count of errors in one file */
-extern int  error_maximum;             /* Limit (raiseable for testing) */
 extern int  error_ptr_correction;      /* For pointing within strings */
 extern int  error_skip;                /* Skip option */
 
-#ifdef SUPPORT_B2PF
-extern b2pf_context **font_b2pf_contexts;  /* Table of B2PF context pointers */
-extern uint32_t *font_b2pf_options;    /* Table of B2PF options */
-#endif
 extern int  font_count;                /* Count of defined fonts */
 extern int  font_basecount;            /* Ditto, as read from file */
 extern uschar *font_IdStrings[];       /* 2-uschar ID strings */
 extern fontstr *font_List;             /* In-store list of fonts */
-extern uschar *font_data_default;      /* Default font data directory */
-extern uschar *font_data_extra;        /* Additional font data directory */
-extern uschar *font_music_default;     /* Default music font directory */
-extern uschar *font_music_extra;       /* Additional music font directory */
+extern uschar *font_metrics_default;   /* Default font metrics directory */
+extern uschar *font_metrics_extra;     /* Additional font metrics directory */
 extern int  font_sinr;                 /* Sin of rotation angle */
 extern int  font_cosr;                 /* Cos of rotation angle */
 extern int  font_stringheight;         /* 2nd value from width function */
@@ -1242,10 +1160,8 @@ extern zcopystr init_zcopy;            /* Default stave zero copy structure */
 extern FILE *input_file;               /* The current input file */
 
 extern uschar length_table[];          /* Table of item lengths */
-extern int  longrest_barwidths[];      /* Fixed widths for longrest bars */
-extern int  longrest_widths[];         /* Widths of longrest symbols */
 
-extern usint main_bit[];               /* Table of bits in a word */
+extern int  main_bit[];                /* Table of bits in a word */
 extern uschar *main_caesurastrings[];  /* For printing caesuras */
 extern int  main_clefoffset[];         /* Offsets in tables for clefs */
 extern int  main_cleftypes[];          /* Types of shape indicators for next */
@@ -1258,7 +1174,6 @@ extern htypestr *main_htypes;          /* Chain of hyphen types */
 extern BOOL main_initialized;          /* True when initialized */
 extern BOOL main_kerning;              /* Kerning flag */
 extern int  main_keysigtable[];        /* Table of sharps and flats */
-extern keytransposestr *main_keytranspose; /* List of explicit transpositions */
 extern int  main_lastmovement;         /* Number of last movement */
 extern int  main_lastpage;             /* Number of last page */
 extern int  main_magnification;        /* Overall magnification */
@@ -1282,7 +1197,7 @@ extern int  main_sheetheight;          /* Height of paper */
 extern int  main_sheetwidth;           /* Width of paper */
 extern BOOL main_shownlogo;            /* FALSE if need to show logo on error */
 extern int  main_stavemagn;            /* Magnification for current stave */
-extern usint main_staves[STAVE_BITVEC_SIZE]; /* External stave selection */
+extern int  main_staves[stave_bitvec_size]; /* External stave selection */
 extern int  main_storetotal;           /* Total store used */
 extern int  main_storestaves;          /* Store used for staves */
 extern int  main_stretchrespacethresh; /* Threshold for re-spacing */
@@ -1294,8 +1209,6 @@ extern int  main_transpose;            /* External transpose value */
 extern BOOL main_transposedaccforce;   /* TRUE => retain accs when transposed */
 extern trkeystr *main_transposedkeys;  /* Transposed keys masquerades */
 extern int  main_truepagelength;       /* Actual page length */
-extern uschar main_xkeys[MAX_XKEYS][10]; /* Custom key signatures */
-extern uschar main_xkeyorder[MAX_XKEYS][10]; /* Acc order for custom keys */
 
 extern uschar *midi_filename;          /* name of MIDI file */
 extern BOOL    midi_for_notes_off;     /* If TRUE, do MIDI even if [notes off] */
@@ -1336,6 +1249,8 @@ extern BOOL print_pamphlet;            /* Printing options */
 extern BOOL print_reverse;
 extern BOOL print_side1;
 extern BOOL print_side2;
+extern uschar *ps_fontdir_default;     /* Default PS font directory */
+extern uschar *ps_fontdir_extra;       /* Additional PS font directory */
 extern uschar *ps_header;              /* Name of PostScript header file */
 
 extern BOOL reading_input;             /* TRUE while reading */
@@ -1345,7 +1260,7 @@ extern stavestr **stavetable;          /* Points to pointers to stave struct */
 
 extern int  stave_bottoms[];           /* Levels of top/bottom lines of staves */
 extern int  stave_tops[];
-extern int  stave_use_draw;            /* Use direct drawing for staves */
+extern BOOL stave_use_draw;            /* Use direct drawing for staves */
 extern BOOL stave_use_widechars;       /* Use 100-pt chars for staves */
 
 extern const int     utf8_table1[];    /* Various tables for UTF-8 processing */
@@ -1365,7 +1280,7 @@ extern uschar version_string[];        /* Identity of program version */
 *                 Global procedures              *
 *************************************************/
 
-extern void debug_printf(const char *, ...);
+extern void debug_printf(char *, ...);
 extern void debug_showbar(int, int, int);
 
 #ifdef Debug
@@ -1380,8 +1295,6 @@ extern uschar *define_find(uschar *);
 
 extern void  error_moan(int, ...);
 
-extern FILE *font_finddata(uschar *, const char *, uschar *, uschar *,
-               uschar *, BOOL);
 extern int   font_fontword(BOOL);
 extern void  font_init(void);
 extern void  font_loadtables(int);
@@ -1389,17 +1302,16 @@ extern void  font_reset(void);
 extern void  font_rotate(int);
 extern int   font_search(uschar *);
 extern int   font_stringwidth(uschar *, int, int);
-extern int   font_utranslate(int, fontstr *);
 
-extern int   format_sprintf(uschar *, const char *, ...);      /* 2nd is format */
-extern int   format_vsprintf(uschar *, const char *, va_list); /* ditto */
+extern int   format_sprintf(uschar *, char *, ...);      /* 2nd is format */
+extern int   format_vsprintf(uschar *, char *, va_list); /* ditto */
 
-extern void  info_printf(const char *, ...);
-extern int   init_command(int, char **, char **, const char *);
+extern void  info_printf(char *, ...);
+extern int   init_command(int, char **, char ***, char *);
 
 extern void  main_tidyup(void);
 
-extern void  midi_write(void);
+extern void  midi_write();
 
 extern void       misc_commoncont(bstr *);
 extern contstr   *misc_copycontstr(contstr *, int, BOOL);
@@ -1427,7 +1339,7 @@ extern uschar *store_copystring(uschar *);
 extern void  store_debug_print(void);
 extern void  store_debug_print(void);
 extern void  store_free(void *);
-extern void *store_get(usint);
+extern void *store_get(int);
 extern void *store_getitem(int);
 extern void *store_nextitem(void);
 extern void *store_Xget(int);
@@ -1438,9 +1350,9 @@ extern uschar *string_read(void);
 extern void    string_stavestring(BOOL);
 extern int     string_width(uschar *, int, int);
 
-extern void  sys_relativize(uschar *, int);
+extern void  sys_relativize(uschar *);
 
-extern int   transpose_key(int, int);
+extern int   transpose_key(int, int, BOOL);
 extern int   transpose_note(int, int *, int *, int, BOOL, BOOL, BOOL, int);
 
 extern BOOL  Tree_InsertNode(tree_node **, tree_node *);
